<template>
  <AnalyticsCard
    :is-loading="isLoading"
    :title="title"
  >
    <div class="size-full p-4">
      <LineChart
        :labels="chartLabels"
        :values="chartValues"
      />
    </div>
  </AnalyticsCard>
</template>

<script lang="ts" setup>
import LineChart, { type DataSet } from "@/js/contexts/shared/ui/components/charts/LineChart.vue";
import dayjs from "dayjs";
import AnalyticsCard from "@/js/contexts/shared/ui/components/analytics/AnalyticsCard.vue";
import useSnowflake from "@/js/contexts/shared/composables/useSnowflake";

const props = defineProps<{
  isLoading: boolean;
  title: string;
  label: string;
  data: { granularity: "year" | "month" | "week" | "day" | "hour"; total: number; labels: string[]; values: number[] } | undefined;
}>();

const { colorVar } = useSnowflake();

const format = computed(() => {
  switch (props.data?.granularity ?? "day") {
    case "year":
      return "YYYY";
    case "month":
      return "MMM YYYY";
    case "day":
      return "D MMM";
    case "hour":
      return "LT";
  }
});

const chartLabels = computed<string[]>(() => props.data?.labels.map((item) => dayjs(item).format(format.value)) ?? []);
const chartValues = computed<DataSet[]>(() => [{ values: props.data?.values ?? [], label: props.label, color: colorVar("--color-primary-500") }]);
</script>
